@@ -1,13 +1,16 @@
+from typing import List
+
+
 class EsRequest:
     search_term: str
-    resources: list[str]
-    filters: list[str]
+    resources: List[str]
+    filters: List[str]
     aggregation: bool
     page: int
     size: int
     analytics: bool
 
-    def __init__(self, search_term: str, resources: list[str] = None, filters: list[str] = None,
+    def __init__(self, search_term: str, resources: List[str] = None, filters: List[str] = None,
                  aggregation: bool = False, page: int = 1, size: int = 10, analytics: bool = False):
         """
         A class used to wrap all necessary input for the search endpoint.
@@ -27,6 +30,7 @@ class EsRequest:
         size : int, default=10
             number of items per page
         analytics : bool, default=False
+            specify if the `analytics` part should be included in the response
         """
         self.search_term = search_term
         self.resources = resources
